@@ -433,7 +433,7 @@ class AtlassianRestAPI(object):
                     error_msg = "\n".join([k + ": " + v for k, v in j.items()])
                 else:
                     error_msg = "\n".join(
-                        j.get("errorMessages", list()) + [k + ": " + v for k, v in j.get("errors", dict()).items()]
+                        j.get("errorMessages", list()) + [k.get("message", "") for k in j.get("errors", dict())]
                     )
             except Exception as e:
                 log.error(e)
